All of lore.kernel.org
 help / color / mirror / Atom feed
* Patch "usb: host: oxu210hp: use new USB_RESUME_TIMEOUT" has been added to the 4.0-stable tree
@ 2015-05-02 13:23 gregkh
  0 siblings, 0 replies; only message in thread
From: gregkh @ 2015-05-02 13:23 UTC (permalink / raw)
  To: balbi, gregkh; +Cc: stable, stable-commits


This is a note to let you know that I've just added the patch titled

    usb: host: oxu210hp: use new USB_RESUME_TIMEOUT

to the 4.0-stable tree which can be found at:
    http://www.kernel.org/git/?p=linux/kernel/git/stable/stable-queue.git;a=summary

The filename of the patch is:
     usb-host-oxu210hp-use-new-usb_resume_timeout.patch
and it can be found in the queue-4.0 subdirectory.

If you, or anyone else, feels it should not be added to the stable tree,
please let <stable@vger.kernel.org> know about it.


>From 84c0d178eb9f3a3ae4d63dc97a440266cf17f7f5 Mon Sep 17 00:00:00 2001
From: Felipe Balbi <balbi@ti.com>
Date: Fri, 13 Feb 2015 14:57:54 -0600
Subject: usb: host: oxu210hp: use new USB_RESUME_TIMEOUT

From: Felipe Balbi <balbi@ti.com>

commit 84c0d178eb9f3a3ae4d63dc97a440266cf17f7f5 upstream.

Make sure we're using the new macro, so our
resume signaling will always pass certification.

Signed-off-by: Felipe Balbi <balbi@ti.com>
Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

---
 drivers/usb/host/oxu210hp-hcd.c |    7 ++++---
 1 file changed, 4 insertions(+), 3 deletions(-)

--- a/drivers/usb/host/oxu210hp-hcd.c
+++ b/drivers/usb/host/oxu210hp-hcd.c
@@ -2500,11 +2500,12 @@ static irqreturn_t oxu210_hcd_irq(struct
 					|| oxu->reset_done[i] != 0)
 				continue;
 
 			/* start 20 msec resume signaling from this port,
 			 * and make hub_wq collect PORT_STAT_C_SUSPEND to
 			 * stop that signaling.
 			 */
-			oxu->reset_done[i] = jiffies + msecs_to_jiffies(20);
+			oxu->reset_done[i] = jiffies +
+				msecs_to_jiffies(USB_RESUME_TIMEOUT);
 			oxu_dbg(oxu, "port %d remote wakeup\n", i + 1);
 			mod_timer(&hcd->rh_timer, oxu->reset_done[i]);
 		}


Patches currently in stable-queue which might be from balbi@ti.com are

queue-4.0/usb-host-xhci-use-new-usb_resume_timeout.patch
queue-4.0/usb-dwc2-hcd-use-new-usb_resume_timeout.patch
queue-4.0/usb-host-sl811-use-new-usb_resume_timeout.patch
queue-4.0/usb-musb-use-new-usb_resume_timeout.patch
queue-4.0/usb-define-a-generic-usb_resume_timeout-macro.patch
queue-4.0/usb-host-oxu210hp-use-new-usb_resume_timeout.patch
queue-4.0/usb-host-isp116x-use-new-usb_resume_timeout.patch
queue-4.0/usb-isp1760-hcd-use-new-usb_resume_timeout.patch
queue-4.0/usb-host-r8a66597-use-new-usb_resume_timeout.patch
queue-4.0/usb-musb-core-fix-tx-rx-endpoint-order.patch
queue-4.0/usb-core-hub-use-new-usb_resume_timeout.patch
queue-4.0/usb-host-fusbh200-use-new-usb_resume_timeout.patch
queue-4.0/usb-gadget-printer-enqueue-printer-s-response-for-setup-request.patch
queue-4.0/usb-host-ehci-use-new-usb_resume_timeout.patch
queue-4.0/usb-host-uhci-use-new-usb_resume_timeout.patch
queue-4.0/usb-host-fotg210-use-new-usb_resume_timeout.patch
queue-4.0/usb-phy-find-the-right-match-in-devm_usb_phy_match.patch

^ permalink raw reply	[flat|nested] only message in thread

only message in thread, other threads:[~2015-05-02 13:24 UTC | newest]

Thread overview: (only message) (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
@@ -2500,11 +2500,12 @@ static irqreturn_t oxu210_hcd_irq(struct
 				continue;
 
-			/* start 20 msec resume signaling from this port,
-			 * and make hub_wq collect PORT_STAT_C_SUSPEND to
+			/* start USB_RESUME_TIMEOUT resume signaling from this
+			 * port, and make hub_wq collect PORT_STAT_C_SUSPEND to
 			 * stop that signaling.
 			 */
2015-05-02 13:23 Patch "usb: host: oxu210hp: use new USB_RESUME_TIMEOUT" has been added to the 4.0-stable tree gregkh

This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.